@@ -57,7 +57,7 @@ if not hasattr(spacy, 'nlp'):
 	from spacy.lang import en
 	spacy.sntbr		= (inst := en.English(), inst.add_pipe("sentencizer"))[0]
 	spacy.snts		= lambda essay, trim=True: [ snt.text.strip() if trim else snt.text for snt in  spacy.sntbr(essay).sents]
-	spacy.sntpid	= lambda essay: (pid:=0, [ ( pid := pid + 1 if "\n" in snt.text else pid,  (snt.text.strip(), pid))[-1] for snt in  spacy.sntbr(essay).sents] )[-1]
+	spacy.sntpid	= lambda essay: (pid:=0, [ ( pid := pid + 1 if "\n" in snt.text else pid,  (snt.text, pid))[-1] for snt in  spacy.sntbr(essay).sents] )[-1]
 	spacy.nlp		= spacy.load('en_core_web_sm')
 	spacy.frombs	= lambda bs: list(spacy.tokens.DocBin().from_bytes(bs).get_docs(spacy.nlp.vocab))[0] if bs else None
 	spacy.tobs		= lambda doc: ( doc_bin:= spacy.tokens.DocBin(), doc_bin.add(doc), doc_bin.to_bytes())[-1]
