@@ -50,6 +50,33 @@ def bar_si(dic):
 	st_pyecharts(b)
 
 
+def bar_data(data, y_label='Count', title=None, subtitle=None ):
+	b = (
+		Bar()
+		.add_xaxis([s for s,i in data])
+		.add_yaxis(y_label, [i for s,i in data])
+		.set_global_opts(
+			title_opts=opts.TitleOpts(
+				title=title, subtitle=subtitle
+			),
+			toolbox_opts=opts.ToolboxOpts(),
+		)
+	)
+	st_pyecharts(
+		b, key="echarts"
+	)  # Add key argument to not remount component at every Streamlit run
+
+def bar_simple(): #https://share.streamlit.io/andfanilo/streamlit-echarts-demo/master/app.py
+	options = {
+    "xAxis": {
+        "type": "category",
+        "data": ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"],
+    },
+    "yAxis": {"type": "value"},
+    "series": [{"data": [120, 200, 150, 80, 70, 110, 130], "type": "bar"}],
+}
+	st_echarts(options=options, height="500px")
+
 from math import log as ln
 def likelihood(a,b,c,d, minus=None):  #from: http://ucrel.lancs.ac.uk/llwizard.html
 	try:
