@@ -1,7 +1,9 @@
 # 2022.2.13
-import requests,json, os, math,re
+import requests,json, os, math,re,traceback
 from elasticsearch import Elasticsearch,helpers
 from collections import	Counter
+import warnings
+warnings.filterwarnings("ignore")
 
 eshost	= os.getenv("eshost", "127.0.0.1") 
 esport	= int(os.getenv("esport", 9200))
@@ -81,6 +83,7 @@ config = {
 			"kps": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
 			"postag": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"skenp": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
+			"sentgram": { "type": "text", "analyzer": "postag_ana","fielddata":"true"}, # simple_complex_headpp compound_question_itis_svo
 			"np": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"ske": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"i": { "type": "integer"},
@@ -266,6 +269,24 @@ def add_mapping(dic:dict, cp:str='testidx'):
 	''' {"num":"integer", "awl":"float", "tag":"keyword"} '''
 	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{k}": { "type": "{v}"  }  }}).text for k,v in dic.items()]
 
+def bulk(arr, batch=100000, debug=False):
+	''' bulk submit , added 2022.3.27, not tested yet '''
+	if not hasattr(bulk, 'actions'):	bulk.actions=[]
+	bulk.actions.append(arr)  #{'_op_type':'index', '_index':idxname, '_id': did, '_source': arr}
+	if len(bulk.actions) > batch : 
+		try:
+			helpers.bulk(client=es,actions=actions, raise_on_error=False)
+			if debug: print (bulk.actions[-1], flush=True) 
+			bulk.actions = []
+		except Exception as ex:
+			print(">>bulk ex:", ex)
+
+	def submit(): 
+		print ("bulk submit is called, un-submiited actions len: ", len(bulk.actions)) 
+		if len(bulk.actions) >0 : 
+			helpers.bulk(client=es,actions=bulk.actions, raise_on_error=False)
+			bulk.actions = []	
+
 def ids(_ids:list, cp:str='inau'): 
 	''' ["one","two"] '''
 	sql	= { 
